@@ -24,13 +24,17 @@ import java.lang.annotation.Annotation;
 import java.lang.reflect.Method;
 import java.util.Iterator;
 import java.util.LinkedHashMap;
+import java.util.List;
 
 import org.simpleframework.xml.Attribute;
 import org.simpleframework.xml.DefaultType;
 import org.simpleframework.xml.Element;
 import org.simpleframework.xml.ElementArray;
 import org.simpleframework.xml.ElementList;
+import org.simpleframework.xml.ElementListUnion;
 import org.simpleframework.xml.ElementMap;
+import org.simpleframework.xml.ElementMapUnion;
+import org.simpleframework.xml.ElementUnion;
 import org.simpleframework.xml.Text;
 import org.simpleframework.xml.Transient;
 import org.simpleframework.xml.Version;
@@ -65,14 +69,9 @@ class MethodScanner extends ContactList {
    private final MethodPartFactory factory;
    
    /**
-    * This is used to acquire the hierarchy for the class scanned.
+    * This object contains various support functions for the class.
     */
-   private final Hierarchy hierarchy;
-   
-   /**
-    * This is the default access type to be used for this scanner.
-    */
-   private final DefaultType access;
+   private final Support support;
    
    /**
     * This is used to collect all the set methods from the object.
@@ -83,44 +82,28 @@ class MethodScanner extends ContactList {
     * This is used to collect all the get methods from the object.
     */
    private final PartMap read;
-   
+
    /**
-    * This is the type of the object that is being scanned.
+    * This contains the details for the class that is being scanned.
     */
-   private final Class type;
-   
+   private final Detail detail;
+      
    /**
     * Constructor for the <code>MethodScanner</code> object. This is
     * used to create an object that will scan the specified class
     * such that all bean property methods can be paired under the
     * XML annotation specified within the class.
     * 
-    * @param type this is the type that is to be scanned for methods
-    * 
-    * @throws Exception thrown if there was a problem scanning
+    * @param detail this contains the details for the class scanned
+    * @param support this contains various support functions
     */
-   public MethodScanner(Class type) throws Exception {
-      this(type, null);
-   }
-   
-   /**
-    * Constructor for the <code>MethodScanner</code> object. This is
-    * used to create an object that will scan the specified class
-    * such that all bean property methods can be paired under the
-    * XML annotation specified within the class.
-    * 
-    * @param type this is the type that is to be scanned for methods
-    * 
-    * @throws Exception thrown if there was a problem scanning
-    */
-   public MethodScanner(Class type, DefaultType access) throws Exception {
-      this.factory = new MethodPartFactory();
-      this.hierarchy = new Hierarchy(type);
+   public MethodScanner(Detail detail, Support support) throws Exception {
+      this.factory = new MethodPartFactory(detail, support);
       this.write = new PartMap();
       this.read = new PartMap();
-      this.access = access;
-      this.type = type;
-      this.scan(type);
+      this.support = support;
+      this.detail = detail;
+      this.scan(detail);
    }
    
    /**
@@ -129,77 +112,80 @@ class MethodScanner extends ContactList {
     * a method is annotated it is converted to a contact so that
     * it can be used during serialization and deserialization.
     * 
-    * @param type this is the type to be scanned for methods
-    * 
-    * @throws Exception thrown if the object schema is invalid
+    * @param detail this contains the details for the class scanned
     */
-   private void scan(Class type) throws Exception {
-      for(Class next : hierarchy) {
-         scan(next, access);
+   private void scan(Detail detail) throws Exception {
+      DefaultType override = detail.getOverride();
+      DefaultType access = detail.getAccess();
+      Class base = detail.getSuper();
+
+      if(base != null) {
+         extend(base, override);
       }
-      for(Class next : hierarchy) {
-         scan(next, type);
-      } 
+      extract(detail, access);
+      extract(detail);
       build();
       validate();
    }
    
+   /**
+    * This method is used to extend the provided class. Extending a
+    * class in this way basically means that the fields that have
+    * been scanned in the specific class will be added to this. Doing
+    * this improves the performance of classes within a hierarchy.
+    * 
+    * @param base the class to inherit scanned fields from
+    * @param access this is the access type used for the super type
+    */
+   private void extend(Class base, DefaultType access) throws Exception {
+      ContactList list = support.getMethods(base, access);
+      
+      for(Contact contact : list) {
+         process((MethodContact)contact);
+      }
+   }
+   
    /**
     * This is used to scan the declared methods within the specified
     * class. Each method will be checked to determine if it contains
     * an XML element and can be used as a <code>Contact</code> for
     * an entity within the object.
     * 
-    * @param real this is the actual type of the object scanned
-    * @param type this is one of the super classes for the object
-    * 
-    * @throws Exception thrown if the class schema is invalid
+    * @param detail this is one of the super classes for the object
     */
-   private void scan(Class type, Class real) throws Exception {
-      Method[] list = type.getDeclaredMethods();
+   private void extract(Detail detail) throws Exception {
+      List<MethodDetail> methods = detail.getMethods();
 
-      for(Method method : list) {
-         scan(method);              
+      for(MethodDetail entry: methods) {
+         Annotation[] list = entry.getAnnotations();
+         Method method = entry.getMethod();
+         
+         for(Annotation label : list) {
+            scan(method, label, list);             
+         }
       }     
    }
    
-   /**
-    * This is used to scan all annotations within the given method.
-    * Each annotation is checked against the set of supported XML
-    * annotations. If the annotation is one of the XML annotations
-    * then the method is considered for acceptance as either a
-    * get method or a set method for the annotated property.
-    * 
-    * @param method the method to be scanned for XML annotations
-    * 
-    * @throws Exception if the method is not a Java Bean method
-    */
-   private void scan(Method method) throws Exception {
-      Annotation[] list = method.getDeclaredAnnotations();
-      
-      for(Annotation label : list) {
-         scan(method, label);                       
-      }  
-   }
-   
    /**
     * This is used to scan all the methods of the class in order to
     * determine if it should have a default annotation. If the method
     * should have a default XML annotation then it is added to the
     * list of contacts to be used to form the class schema.
     * 
-    * @param type this is the type to have its methods scanned
+    * @param detail this is the detail to have its methods scanned
     * @param access this is the default access type for the class
     */
-   private void scan(Class type, DefaultType access) throws Exception {
-      Method[] list = type.getDeclaredMethods();
+   private void extract(Detail detail, DefaultType access) throws Exception {
+      List<MethodDetail> methods = detail.getMethods();
 
       if(access == PROPERTY) {
-         for(Method method : list) {
+         for(MethodDetail entry : methods) {
+            Annotation[] list = entry.getAnnotations();
+            Method method = entry.getMethod();
             Class value = factory.getType(method);
             
             if(value != null) {
-               process(method);
+               process(method, list);
             }
          }  
       }
@@ -213,33 +199,41 @@ class MethodScanner extends ContactList {
     * 
     * @param method the method that the annotation comes from
     * @param label the annotation used to model the XML schema
-    * 
-    * @throws Exception if there is more than one text annotation
+    * @param list this is the list of annotations on the method
     */ 
-   private void scan(Method method, Annotation label) throws Exception {
+   private void scan(Method method, Annotation label, Annotation[] list) throws Exception {
       if(label instanceof Attribute) {
-         process(method, label);
+         process(method, label, list);
+      }
+      if(label instanceof ElementUnion) {
+         process(method, label, list);
+      }
+      if(label instanceof ElementListUnion) {
+         process(method, label, list);
+      }
+      if(label instanceof ElementMapUnion) {
+         process(method, label, list);
       }
       if(label instanceof ElementList) {
-         process(method, label);
+         process(method, label, list);
       }
       if(label instanceof ElementArray) {
-         process(method, label);
+         process(method, label, list);
       }
       if(label instanceof ElementMap) {
-         process(method, label);
+         process(method, label, list);
       }
       if(label instanceof Element) {
-         process(method, label);
+         process(method, label, list);
       }    
-      if(label instanceof Transient) {
-         remove(method, label);
-      }
       if(label instanceof Version) {
-         process(method, label);
+         process(method, label, list);
       }
       if(label instanceof Text) {
-         process(method, label);
+         process(method, label, list);
+      }
+      if(label instanceof Transient) {
+         remove(method, label, list);
       }
    }
   
@@ -253,9 +247,10 @@ class MethodScanner extends ContactList {
     * 
     * @param method this is the method that is to be classified
     * @param label this is the annotation applied to the method
+    * @param list this is the list of annotations on the method
     */  
-   private void process(Method method, Annotation label) throws Exception {
-      MethodPart part = factory.getInstance(method, label);
+   private void process(Method method, Annotation label, Annotation[] list) throws Exception {
+      MethodPart part = factory.getInstance(method, label, list);
       MethodType type = part.getMethodType();     
       
       if(type == MethodType.GET) {
@@ -278,9 +273,10 @@ class MethodScanner extends ContactList {
     * write map so that it can be paired after scanning is complete.
     * 
     * @param method this is the method that is to be classified
+    * @param list this is the list of annotations on the method
     */  
-   private void process(Method method) throws Exception {
-      MethodPart part = factory.getInstance(method);
+   private void process(Method method, Annotation[] list) throws Exception {
+      MethodPart part = factory.getInstance(method, list);
       MethodType type = part.getMethodType();     
       
       if(type == MethodType.GET) {
@@ -311,6 +307,63 @@ class MethodScanner extends ContactList {
       }
    }
    
+   /**
+    * This is used to process a method from a super class. Processing
+    * the inherited method involves extracting out the individual
+    * parts of the method an initializing the internal state of this
+    * scanner. If method is overridden it overwrites the parts.
+    * 
+    * @param contact this is a method inherited from a super class
+    */
+   private void process(MethodContact contact) {
+      MethodPart get = contact.getRead();
+      MethodPart set = contact.getWrite();
+      
+      if(set != null) {
+         insert(set, write);
+      }
+      insert(get, read);
+   }
+   
+   /**
+    * This is used to insert a contact to this contact list. Here if
+    * a <code>Text</code> annotation is declared on a method that
+    * already has an annotation then the other annotation is given
+    * the priority, this is to so text can be processes separately.
+    * 
+    * @param method this is the part that is to be inserted
+    * @param map this is the map that the part is to be inserted in
+    */
+   private void insert(MethodPart method, PartMap map) {
+      String name = method.getName();
+      MethodPart existing = map.remove(name);
+      
+      if(existing != null) {
+         if(isText(method)) {
+            method = existing;
+         }
+      }
+      map.put(name, method);
+   }
+      
+   /**
+    * This is used to determine if the <code>Text</code> annotation
+    * has been declared on the method. If this annotation is used
+    * then this will return true, otherwise this returns false.
+    * 
+    * @param contact the contact to check for the text annotation
+    * 
+    * @return true if the text annotation was declared on the method
+    */
+   private boolean isText(MethodPart method) {
+      Annotation label = method.getAnnotation();
+      
+      if(label instanceof Text) {
+         return true;
+      }
+      return false;
+   }
+   
    /**
     * This method is used to remove a particular method from the list
     * of contacts. If the <code>Transient</code> annotation is used
@@ -320,9 +373,10 @@ class MethodScanner extends ContactList {
     * 
     * @param method this is the method that is to be removed
     * @param label this is the label associated with the method
+    * @param list this is the list of annotations on the method
     */
-   private void remove(Method method, Annotation label) throws Exception {
-      MethodPart part = factory.getInstance(method, label);
+   private void remove(Method method, Annotation label, Annotation[] list) throws Exception {
+      MethodPart part = factory.getInstance(method, label, list);
       MethodType type = part.getMethodType();     
       
       if(type == MethodType.GET) {
@@ -359,8 +413,6 @@ class MethodScanner extends ContactList {
     * names must match exactly, meaning that the case and value of
     * the strings must be identical. Also in order for this to succeed
     * the types for the methods and the annotation must also match.
-    *  
-    * @throws Exception thrown if there is a problem matching methods
     */
    private void build() throws Exception {
       for(String name : read) {
@@ -380,9 +432,7 @@ class MethodScanner extends ContactList {
     * the types for the methods and the annotation must also match.
     * 
     * @param read this is a get method that has been extracted
-    * @param name this is the Java Bean methods name to be matched   
-    *  
-    * @throws Exception thrown if there is a problem matching methods
+    * @param name this is the Java Bean methods name to be matched
     */
    private void build(MethodPart read, String name) throws Exception {      
       MethodPart match = write.take(name);
@@ -390,7 +440,7 @@ class MethodScanner extends ContactList {
       if(match != null) {
          build(read, match);
       } else {
-         build(read); // read only
+         build(read); 
       }
    }   
    
@@ -400,9 +450,7 @@ class MethodScanner extends ContactList {
     * by the class schema. So, read only methods can be used in a 
     * fully serializable and deserializable object.
     * 
-    * @param read this is the part to add as a read only contact      
-    *  
-    * @throws Exception thrown if there is a problem matching methods
+    * @param read this is the part to add as a read only contact
     */
    private void build(MethodPart read) throws Exception {
       add(new MethodContact(read));
@@ -416,16 +464,14 @@ class MethodScanner extends ContactList {
     * the types for the methods and the annotation must also match.
     * 
     * @param read this is a get method that has been extracted
-    * @param write this is the write method to compare details with      
-    *  
-    * @throws Exception thrown if there is a problem matching methods
+    * @param write this is the write method to compare details with    
     */
    private void build(MethodPart read, MethodPart write) throws Exception {
       Annotation label = read.getAnnotation();
       String name = read.getName();
       
       if(!write.getAnnotation().equals(label)) {
-         throw new MethodException("Annotations do not match for '%s' in %s", name, type);
+         throw new MethodException("Annotations do not match for '%s' in %s", name, detail);
       }
       Class type = read.getType();
       
@@ -440,8 +486,6 @@ class MethodScanner extends ContactList {
     * have been matched with a set method. This ensures that there
     * is not a set method within the object that does not have a
     * match, therefore violating the contract of a property.
-    * 
-    * @throws Exception thrown if there is a unmatched set method
     */
    private void validate() throws Exception {
       for(String name : write) {
@@ -461,15 +505,13 @@ class MethodScanner extends ContactList {
     * 
     * @param write this is a get method that has been extracted
     * @param name this is the Java Bean methods name to be matched 
-    * 
-    * @throws Exception thrown if there is a unmatched set method
     */
    private void validate(MethodPart write, String name) throws Exception {      
       MethodPart match = read.take(name);     
       Method method = write.getMethod();      
          
       if(match == null) {
-         throw new MethodException("No matching get method for %s in %s", method, type);
+         throw new MethodException("No matching get method for %s in %s", method, detail);
       }      
    }
    
@@ -481,7 +523,7 @@ class MethodScanner extends ContactList {
     * 
     * @see org.simpleframework.xml.core.MethodPart
     */
-   private class PartMap extends LinkedHashMap<String, MethodPart> implements Iterable<String>{
+   private static class PartMap extends LinkedHashMap<String, MethodPart> implements Iterable<String>{
       
       /**
        * This returns an iterator for the Java Bean method names for
