@@ -2,11 +2,8 @@ package org.simpleframework.xml;
 
 import java.io.File;
 import java.io.FileOutputStream;
-import java.io.OutputStream;
-import java.io.OutputStreamWriter;
 import java.io.StringReader;
 import java.io.StringWriter;
-import java.io.Writer;
 import java.util.ArrayList;
 import java.util.LinkedList;
 import java.util.List;
@@ -16,13 +13,9 @@ import java.util.regex.Pattern;
 
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
-import javax.xml.transform.OutputKeys;
-import javax.xml.transform.Transformer;
-import javax.xml.transform.TransformerFactory;
-import javax.xml.transform.dom.DOMSource;
-import javax.xml.transform.stream.StreamResult;
 
-import org.custommonkey.xmlunit.XMLTestCase;
+import junit.framework.TestCase;
+
 import org.simpleframework.xml.core.Persister;
 import org.simpleframework.xml.strategy.CycleStrategy;
 import org.simpleframework.xml.strategy.Strategy;
@@ -33,7 +26,6 @@ import org.simpleframework.xml.stream.CamelCaseStyle;
 import org.simpleframework.xml.stream.Format;
 import org.simpleframework.xml.stream.HyphenStyle;
 import org.simpleframework.xml.stream.InputNode;
-//import org.simpleframework.xml.stream.NodeAdapterBuilder;
 import org.simpleframework.xml.stream.NodeMap;
 import org.simpleframework.xml.stream.OutputNode;
 import org.simpleframework.xml.stream.Style;
@@ -44,14 +36,12 @@ import org.w3c.dom.NodeList;
 import org.xml.sax.InputSource;
 
 
-public class ValidationTestCase extends XMLTestCase {
+public class ValidationTestCase extends TestCase {
 
-   private static TransformerFactory transformerFactory;
-  
-	private static Transformer transformer;   
+   //private static TransformerFactory transformerFactory;
+	//private static Transformer transformer;   
    
    private static DocumentBuilderFactory builderFactory;
-
    private static DocumentBuilder builder;
         
    static  {
@@ -60,87 +50,75 @@ public class ValidationTestCase extends XMLTestCase {
          builderFactory.setNamespaceAware(true);
          builder = builderFactory.newDocumentBuilder();
 
-         transformerFactory = TransformerFactory.newInstance();
-         transformer = transformerFactory.newTransformer();
+         //transformerFactory = TransformerFactory.newInstance();
+         //transformer = transformerFactory.newTransformer();
       } catch(Exception cause) {
          cause.printStackTrace();              
       }         
    }
 
-   private static File directory;
-
-   static {
-        try {
-            String path = System.getProperty("output");                                       
-            directory = new File(path);
-        } catch(Exception cause){
-            directory = new File("output");
-        }         
-        if(!directory.exists()) {
-            directory.mkdirs();                
-        }
-   }
-
    public void testDirectory() throws Exception {
-      assertTrue(directory.exists());           
+      assertTrue(FileSystem.validFileSystem());           
    }
 
    public static synchronized void validate(Serializer out, Object type) throws Exception {
       validate(type, out);
    }
     public static synchronized void validate(Object type, Serializer out) throws Exception {
-        File destination = new File(directory, type.getClass().getSimpleName() + ".xml");
-        OutputStream file = new FileOutputStream(destination);
+        String fileName = type.getClass().getSimpleName() + ".xml";
         StringWriter buffer = new StringWriter();
         out.write(type, buffer);
         String text = buffer.toString();
         byte[] octets = text.getBytes("UTF-8");
         System.out.write(octets);
         System.out.flush();
-        file.write(octets);
-        file.close();        
+        FileSystem.writeBytes(fileName, octets);       
         validate(text);
         
-        File domDestination = new File(directory, type.getClass().getSimpleName() + ".dom.xml");
-        File asciiDestination = new File(directory, type.getClass().getSimpleName() + ".ascii-dom.xml");
-        OutputStream domFile = new FileOutputStream(domDestination);
-        OutputStream asciiFile = new FileOutputStream(asciiDestination);
-        Writer asciiOut = new OutputStreamWriter(asciiFile, "iso-8859-1");
+        //File domDestination = new File(directory, type.getClass().getSimpleName() + ".dom.xml");
+        //File asciiDestination = new File(directory, type.getClass().getSimpleName() + ".ascii-dom.xml");
+        //OutputStream domFile = new FileOutputStream(domDestination);
+        //OutputStream asciiFile = new FileOutputStream(asciiDestination);
+        //Writer asciiOut = new OutputStreamWriter(asciiFile, "iso-8859-1");
         
         /*
          * This DOM document is the result of serializing the object in to a 
          * string. The document can then be used to validate serialization.
          */
-        Document doc = builder.parse(new InputSource(new StringReader(text)));   
+        //Document doc = builder.parse(new InputSource(new StringReader(text)));   
         
-        transformer.setOutputProperty(OutputKeys.INDENT, "yes");
-        transformer.transform(new DOMSource(doc), new StreamResult(domFile));
-        transformer.transform(new DOMSource(doc), new StreamResult(asciiOut));    
+        //transformer.setOutputProperty(OutputKeys.INDENT, "yes");
+        //transformer.transform(new DOMSource(doc), new StreamResult(domFile));
+        //transformer.transform(new DOMSource(doc), new StreamResult(asciiOut));    
         
-        domFile.close();      
-        asciiFile.close();
+        //domFile.close();      
+        //asciiFile.close();
         out.validate(type.getClass(), text);
        
-        File hyphenFile = new File(directory, type.getClass().getSimpleName() + ".hyphen.xml");
+        String hyphenFile =  type.getClass().getSimpleName() + ".hyphen.xml";
         Strategy strategy = new CycleStrategy("ID", "REFERER");
         Visitor visitor = new DebugVisitor();
         strategy = new VisitorStrategy(visitor, strategy);
         Style style = new HyphenStyle();
         Format format = new Format(style);
         Persister hyphen = new Persister(strategy, format);
+        StringWriter hyphenWriter = new StringWriter();
         
-        hyphen.write(type, hyphenFile);
+        hyphen.write(type, hyphenWriter);
         hyphen.write(type, System.out);
-        hyphen.read(type.getClass(), hyphenFile);
+        hyphen.read(type.getClass(), hyphenWriter.toString());
+        FileSystem.writeString(hyphenFile, hyphenWriter.toString());
         
-        File camelCaseFile = new File(directory, type.getClass().getSimpleName() + ".camel-case.xml");
+        String camelCaseFile = type.getClass().getSimpleName() + ".camel-case.xml";
         Style camelCaseStyle = new CamelCaseStyle(true, false);
         Format camelCaseFormat = new Format(camelCaseStyle);
         Persister camelCase = new Persister(strategy, camelCaseFormat);
-        
-        camelCase.write(type, camelCaseFile);
+        StringWriter camelCaseWriter =  new StringWriter();
+       
+        camelCase.write(type, camelCaseWriter);
         camelCase.write(type, System.out);
-        camelCase.read(type.getClass(), camelCaseFile);
+        camelCase.read(type.getClass(), camelCaseWriter.toString());
+        FileSystem.writeString(camelCaseFile, camelCaseWriter.toString());
     }
     
     public static synchronized Document parse(String text) throws Exception {
@@ -224,7 +202,7 @@ public class ValidationTestCase extends XMLTestCase {
              int index = 0;
              if(matcher.matches()) {
                 String value = matcher.group(2);
-                index = Integer.parseInt(value);
+                index = Integer.parseInt(value) -1;
                 path = matcher.group(1);
              }
              List<org.w3c.dom.Element> list = getElementsByTagName(element, path);
@@ -243,7 +221,7 @@ public class ValidationTestCase extends XMLTestCase {
        }
     }
     
-    public static List<org.w3c.dom.Element> getElementsByTagName(org.w3c.dom.Element element, String name) {
+    private static List<org.w3c.dom.Element> getElementsByTagName(org.w3c.dom.Element element, String name) {
        List<org.w3c.dom.Element> list = new ArrayList<org.w3c.dom.Element>();
        NodeList allElements = element.getElementsByTagName("*");
        for(int i = 0; i < allElements.getLength(); i++) {
@@ -279,12 +257,12 @@ public class ValidationTestCase extends XMLTestCase {
        return null;  
     }
     
-    public static interface ExpressionMatch{
+    private static interface ExpressionMatch{
        public boolean match(org.w3c.dom.Element element);
        public String getDescription();
     }
     
-    public static class MatchAny implements ExpressionMatch {
+    private static class MatchAny implements ExpressionMatch {
        public boolean match(org.w3c.dom.Element element) {
           return element != null;
        }
@@ -293,7 +271,7 @@ public class ValidationTestCase extends XMLTestCase {
        }
     }
     
-    public static class ElementMatch implements ExpressionMatch {
+    private static class ElementMatch implements ExpressionMatch {
        private final String text;
        public ElementMatch(String text){
           this.text = text;
@@ -310,7 +288,7 @@ public class ValidationTestCase extends XMLTestCase {
        }
     }
     
-    public static class ElementCDATAMatch implements ExpressionMatch {
+    private static class ElementCDATAMatch implements ExpressionMatch {
        private final String text;
        public ElementCDATAMatch(String text){
           this.text = text;
@@ -330,7 +308,7 @@ public class ValidationTestCase extends XMLTestCase {
        }
     }
     
-    public static class NamespaceMatch implements ExpressionMatch {
+    private static class NamespaceMatch implements ExpressionMatch {
        private final String reference;
        public NamespaceMatch(String reference) {
           this.reference = reference;
@@ -371,7 +349,7 @@ public class ValidationTestCase extends XMLTestCase {
        }
     }
     
-    public static class OfficialNamespaceMatch implements ExpressionMatch {
+    private static class OfficialNamespaceMatch implements ExpressionMatch {
        private final String reference;
        public OfficialNamespaceMatch(String reference) {
           this.reference = reference;
@@ -391,7 +369,7 @@ public class ValidationTestCase extends XMLTestCase {
        }
     }
     
-    public static class AttributeMatch implements ExpressionMatch {
+    private static class AttributeMatch implements ExpressionMatch {
        private final String name;
        private final String value;
        public AttributeMatch(String name, String value) {
@@ -434,7 +412,7 @@ public class ValidationTestCase extends XMLTestCase {
        print(doc.getDocumentElement());
      }
    
-     public static class DebugVisitor implements Visitor {
+     private static class DebugVisitor implements Visitor {
         public void read(Type type, NodeMap<InputNode> node){
            InputNode element = node.getNode();
            if(element.isRoot()) {
@@ -450,5 +428,43 @@ public class ValidationTestCase extends XMLTestCase {
            }
         }
      }
+     public static class FileSystem {
+        public static File getDirectory() {
+           File directory = null; 
+            try{
+                 String path = System.getProperty("output"); 
+                 if(path != null) {
+                    directory = new File(path);
+                 }
+             } catch(Exception e){
+                e.printStackTrace();
+             }         
+             if(directory == null) {
+                directory = new File("output");
+             }
+             if(!directory.exists()) {
+                directory.mkdirs();                
+            }
+            return directory;
+        }
+        public static boolean validFileSystem() {
+           return getDirectory().exists();
+        }
+        public static void writeString(String fileName, String content) {
+           writeBytes(fileName, content.getBytes());
+        }
+        public static void writeBytes(String fileName, byte[] content) {
+           try {
+              File directory = getDirectory();
+              File file = new File(directory, fileName);
+              FileOutputStream out = new FileOutputStream(file);
+              out.write(content);
+              out.flush();
+              out.close();
+           }catch(Exception e){
+              System.err.println(e.getMessage());
+           }
+        }
+     }
 
 }
