@@ -1,15 +1,12 @@
 package org.simpleframework.xml.core;
 
-import java.io.StringReader;
 import java.io.StringWriter;
 
 import org.simpleframework.xml.Attribute;
 import org.simpleframework.xml.Element;
 import org.simpleframework.xml.Root;
-import org.simpleframework.xml.core.Persister;
-import org.simpleframework.xml.stream.Format;
-
 import org.simpleframework.xml.ValidationTestCase;
+import org.simpleframework.xml.stream.Format;
 
 public class PrologTest extends ValidationTestCase {
 
